<?php
/**
 * @see https://github.com/WordPress/gutenberg/blob/trunk/docs/reference-guides/block-api/block-metadata.md#render
 */

// get per_page from block attributes
$per_page = $attributes['perPage'] ?? -1;
$category = $attributes['category'] ?? '';
$showExcerpt = $attributes['showExcerpt'] ?? false;
$grid = $attributes['grid'] ?? false;

$query_args = array(
    'post_type' => 'product',
    'posts_per_page' => $per_page,
);

if ($category) {
    $query_args['tax_query'] = array(
        array(
            'taxonomy' => 'product_cat',
            'terms' => $category,
        ),
    );
}


$products = new WP_Query($query_args);
?>
<div <?php echo get_block_wrapper_attributes(
    array(
        'class' => $grid ? 'grid' : '',
    )
); ?>>
    <?php if ($products->have_posts()): ?>
        <?php while ($products->have_posts()):
            $products->the_post(); ?>
            <div class="devhuset-blocks-product-list__item">
                <?php the_post_thumbnail($grid ? 'medium_large' : 'full'); ?>

                <div class="devhuset-blocks-product-list__item-content">
                    <div>
                        <h2><?php the_title(); ?></h2>
                        <?php if ($showExcerpt) { ?>
                            <p><?php echo get_post_field('post_excerpt', the_ID()); ?></p>
                        <?php } ?>
                    </div>
                    <div class="wp-block-button">
                        <a href="<?php the_permalink(); ?>" class="wp-block-button__link wp-element-button">
                            <?php _e('Read more', 'devhuset-blocks'); ?>
                        </a>
                    </div>
                </div>
            </div>
        <?php endwhile; ?>
    <?php else: ?>
        <p>No products found</p>
    <?php endif; ?>
</div>